==> green-core-1.70.1.tgz: package/components/form/form-control.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateSet
} from "../../chunks/chunk.QTSIPXV3.js";
var _internals;
import { msg } from "@lit/localize";
import { property } from "lit/decorators.js";
import { GdsElement } from "../../gds-element";
import { watch } from "../../utils/decorators";
class GdsFormControlElement extends GdsElement {
  constructor() {
    super();
    __privateAdd(this, _internals, void 0);
    this.required = false;
    this.errorMessage = "";
    this.label = "";
    this.name = "";
    this.disabled = false;
    try {
      __privateSet(this, _internals, this.attachInternals());
    } catch (e) {
      __privateSet(this, _internals, {
        form: this.closest("form"),
        setFormValue: (value) => {
          this.value = value;
        },
        setValidity: (validity, validationMessage) => {
          ;
          __privateGet(this, _internals).validity = validity;
          this.errorMessage = validationMessage || "";
        },
        validationMessage: "",
        validity: {
          badInput: false,
          customError: false,
          patternMismatch: false,
          rangeOverflow: false,
          rangeUnderflow: false,
          stepMismatch: false,
          tooLong: false,
          tooShort: false,
          typeMismatch: false,
          valueMissing: false,
          valid: true
        },
        willValidate: true,
        checkValidity: () => true,
        reportValidity: () => true
      });
    }
  }
  set invalid(value) {
    const oldValue = this.invalid;
    __privateGet(this, _internals).setValidity(
      {
        ...__privateGet(this, _internals).validity,
        customError: value,
        valid: !value
      },
      this.validationMessage || msg(`Error message.`),
      // @ts-expect-error - setValidity actually takes an element as the third argument, but the type definition is wrong.
      this._getValidityAnchor() || void 0
    );
    this.requestUpdate("invalid", oldValue);
    __privateGet(this, _internals).checkValidity();
  }
  get invalid() {
    return !__privateGet(this, _internals).validity.valid;
  }
  get value() {
    return this._internalValue;
  }
  set value(value) {
    this._internalValue = value;
  }
  /**
   * The form element that the form control is associated with.
   */
  get form() {
    return __privateGet(this, _internals).form;
  }
  get validity() {
    return __privateGet(this, _internals).validity;
  }
  get validationMessage() {
    return __privateGet(this, _internals).validationMessage;
  }
  get willValidate() {
    return __privateGet(this, _internals).willValidate;
  }
  checkValidity() {
    const anchor = this._getValidityAnchor();
    if (!anchor || !this.validator)
      return true;
    const oldValue = this.invalid;
    const validity = this.validator.validate(this) || [
      { ...this.validity, valid: true },
      ""
    ];
    __privateGet(this, _internals).setValidity(
      validity[0],
      validity[1],
      // @ts-expect-error - setValidity actually takes an element as the third argument, but the type definition is wrong.
      this._getValidityAnchor()
    );
    if (oldValue !== this.invalid)
      this.requestUpdate();
    return __privateGet(this, _internals).checkValidity();
  }
  reportValidity() {
    return __privateGet(this, _internals).reportValidity();
  }
  __handleValueChange() {
    __privateGet(this, _internals).setFormValue(this.value);
    this.checkValidity();
  }
  formResetCallback() {
    if (typeof this.value === "string")
      this.value = "";
    else
      this.value = void 0;
  }
  formAssociatedCallback(form) {
    form?.addEventListener("submit", this._handleFormSubmit.bind(this));
  }
  _handleFormSubmit(e) {
    this.checkValidity();
    if (!this.validity.valid)
      e.preventDefault();
  }
  focus(options) {
    this._getValidityAnchor().focus(options);
  }
}
_internals = new WeakMap();
GdsFormControlElement.formAssociated = true;
__decorateClass([
  property({ attribute: false })
], GdsFormControlElement.prototype, "validator", 2);
__decorateClass([
  property({ type: Boolean })
], GdsFormControlElement.prototype, "required", 2);
__decorateClass([
  property({ attribute: "error-message" })
], GdsFormControlElement.prototype, "errorMessage", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true,
    attribute: "aria-invalid",
    converter: {
      fromAttribute: Boolean,
      toAttribute: (value) => value?.toString()
    }
  })
], GdsFormControlElement.prototype, "invalid", 1);
__decorateClass([
  property()
], GdsFormControlElement.prototype, "label", 2);
__decorateClass([
  property()
], GdsFormControlElement.prototype, "value", 1);
__decorateClass([
  property({ reflect: true })
], GdsFormControlElement.prototype, "name", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsFormControlElement.prototype, "disabled", 2);
__decorateClass([
  watch("value")
], GdsFormControlElement.prototype, "__handleValueChange", 1);
export {
  GdsFormControlElement
};

==> green-core-1.76.1.tgz: package/components/form/form-control.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateSet
} from "../../chunks/chunk.QTSIPXV3.js";
var _internals;
import { msg } from "@lit/localize";
import { property } from "lit/decorators.js";
import { GdsElement } from "../../gds-element.js";
import { watch } from "../../utils/decorators/index.js";
class GdsFormControlElement extends GdsElement {
  constructor() {
    super();
    __privateAdd(this, _internals, void 0);
    this.required = false;
    this.errorMessage = "";
    this.label = "";
    this.name = "";
    this.disabled = false;
    try {
      __privateSet(this, _internals, this.attachInternals());
    } catch (e) {
      __privateSet(this, _internals, {
        form: this.closest("form"),
        setFormValue: (value) => {
          this.value = value;
        },
        setValidity: (validity, validationMessage) => {
          ;
          __privateGet(this, _internals).validity = validity;
          this.errorMessage = validationMessage || "";
        },
        validationMessage: "",
        validity: {
          badInput: false,
          customError: false,
          patternMismatch: false,
          rangeOverflow: false,
          rangeUnderflow: false,
          stepMismatch: false,
          tooLong: false,
          tooShort: false,
          typeMismatch: false,
          valueMissing: false,
          valid: true
        },
        willValidate: true,
        checkValidity: () => true,
        reportValidity: () => true
      });
    }
  }
  set invalid(value) {
    const oldValue = this.invalid;
    __privateGet(this, _internals).setValidity(
      {
        ...__privateGet(this, _internals).validity,
        customError: value,
        valid: !value
      },
      this.validationMessage || msg(`Error message.`),
      // @ts-expect-error - setValidity actually takes an element as the third argument, but the type definition is wrong.
      this._getValidityAnchor() || void 0
    );
    this.requestUpdate("invalid", oldValue);
    __privateGet(this, _internals).checkValidity();
  }
  get invalid() {
    return !__privateGet(this, _internals).validity.valid;
  }
  get value() {
    return this._internalValue;
  }
  set value(value) {
    this._internalValue = value;
  }
  /**
   * The form element that the form control is associated with.
   */
  get form() {
    return __privateGet(this, _internals).form;
  }
  get validity() {
    return __privateGet(this, _internals).validity;
  }
  get validationMessage() {
    return __privateGet(this, _internals).validationMessage;
  }
  get willValidate() {
    return __privateGet(this, _internals).willValidate;
  }
  checkValidity() {
    const anchor = this._getValidityAnchor();
    if (!anchor || !this.validator)
      return true;
    const oldValue = this.invalid;
    const validity = this.validator.validate(this) || [
      { ...this.validity, valid: true },
      ""
    ];
    __privateGet(this, _internals).setValidity(
      validity[0],
      validity[1],
      // @ts-expect-error - setValidity actually takes an element as the third argument, but the type definition is wrong.
      this._getValidityAnchor()
    );
    if (oldValue !== this.invalid)
      this.requestUpdate();
    return __privateGet(this, _internals).checkValidity();
  }
  reportValidity() {
    return __privateGet(this, _internals).reportValidity();
  }
  __handleValueChange() {
    __privateGet(this, _internals).setFormValue(this.value);
    this.checkValidity();
  }
  formResetCallback() {
    if (typeof this.value === "string")
      this.value = "";
    else
      this.value = void 0;
  }
  formAssociatedCallback(form) {
    form?.addEventListener("submit", this._handleFormSubmit.bind(this));
  }
  _handleFormSubmit(e) {
    this.checkValidity();
    if (!this.validity.valid)
      e.preventDefault();
  }
  focus(options) {
    this._getValidityAnchor().focus(options);
  }
}
_internals = new WeakMap();
GdsFormControlElement.formAssociated = true;
__decorateClass([
  property({ attribute: false })
], GdsFormControlElement.prototype, "validator", 2);
__decorateClass([
  property({ type: Boolean })
], GdsFormControlElement.prototype, "required", 2);
__decorateClass([
  property({ attribute: "error-message" })
], GdsFormControlElement.prototype, "errorMessage", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true,
    attribute: "aria-invalid",
    converter: {
      fromAttribute: Boolean,
      toAttribute: (value) => value?.toString()
    }
  })
], GdsFormControlElement.prototype, "invalid", 1);
__decorateClass([
  property()
], GdsFormControlElement.prototype, "label", 2);
__decorateClass([
  property()
], GdsFormControlElement.prototype, "value", 1);
__decorateClass([
  property({ reflect: true })
], GdsFormControlElement.prototype, "name", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsFormControlElement.prototype, "disabled", 2);
__decorateClass([
  watch("value")
], GdsFormControlElement.prototype, "__handleValueChange", 1);
export {
  GdsFormControlElement
};
